cEVI_fun: Calculation of the convergence Epidemic Volatility Index
Description
This sencondary function produces the convergence Epidemic Volatility Index based on input data.
Usage
cEVI_fun(cases, lag_n, c_n)
Value
Dates: the date for each time point (with origin 01-01-1970).
Days: the serial number for each time point.
EVI: the estimated EVI for each time point.
Arguments
cases
the time series of the newly observed cases per unit of time (ideally per day).
lag_n
Integer. Restriction of the window size for the rolling window size.
c_n
threshold alpha-level value (0 <= c <= 0.5) for issuing an early warning. If cevi <= c_n an early warning is issued and otherwise is not.
For each time point the stored variables are:
References
Pateras K, Meletis E, Denwood M, et al. The convergence epidemic index (cEVI) an early warning tool for identifying waves in an epidemic. Inf Dis Mod, (2023)